.. hydro documentation master file, created by
   sphinx-quickstart on Wed Sep 19 15:15:28 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to hydro's documentation!
=================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   getting_started
   format_spec
   attributes
   erddap
   ODF_CCHDO_netCDF_ops
   exchange_checker
   notebooks
   changelog


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
